Documentation
¶
Overview ¶
Package zeroms is a CoreDNS plugin that provides landing page and statistics functionality.
Index ¶
- type Stats
- func (s *Stats) AddLatency(duration time.Duration)
- func (s *Stats) AddUpstreamLatency(duration time.Duration)
- func (s *Stats) Clone() *Stats
- func (s *Stats) GetStats() map[string]interface{}
- func (s *Stats) IncrementCounter(counter *uint64)
- func (s *Stats) Reset()
- func (s *Stats) RestoreFrom(other *Stats)
- type Zeroms
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Stats ¶
type Stats struct {
StartTime time.Time
TotalRequests uint64
ErrorCount uint64
UpstreamRequests uint64
CacheHits uint64
CacheMisses uint64
TotalLatency int64
UpstreamLatency int64
// contains filtered or unexported fields
}
Stats holds DNS server statistics
func (*Stats) AddLatency ¶
AddLatency atomically adds latency measurement
func (*Stats) AddUpstreamLatency ¶
AddUpstreamLatency atomically adds upstream latency measurement
func (*Stats) IncrementCounter ¶
IncrementCounter atomically increments a counter
func (*Stats) RestoreFrom ¶
RestoreFrom safely restores stats data from another Stats instance
Click to show internal directories.
Click to hide internal directories.